//info: Basic window component to display content and buttons of a page, inclduing header and footer
//content to insert is placed in the content prop, and buttons in the buttons prop
import Header from "./Header";
import Footer from "./Footer";

/**
 * Renders a basic window component with a header, content, and footer.
 *
 * @param {Object} props - The component props.
 * @param {React.ReactNode} props.content - The content to be rendered in the window.
 * @param {React.ReactNode} props.buttons - The buttons to be rendered in the footer.
 * @returns {JSX.Element} The rendered basic window component.
 */
function BasicWindow({
  content,
  buttons,
}: {
  content: React.ReactNode;
  buttons: React.ReactNode;
}): JSX.Element {
  return (
    <div className="font-sans flex flex-col h-screen bg-white border-2 border-black overflow-auto pt-[110px]">
      <Header />
      <div className="flex flex-col items-center flex-grow">{content}</div>
      <Footer>{buttons}</Footer>
    </div>
  );
}

export default BasicWindow;
